"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.GridSection = exports.Section = void 0;

var _styledComponents = _interopRequireDefault(require("styled-components"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

(function () {
  var enterModule = require('react-hot-loader').enterModule;

  enterModule && enterModule(module);
})();

/**
 * Exporting Styled Components
 */

/** ************************************************/

/** ***************** DIV STYLING *****************/

/** ************************************************/

/**
 * Section Component
 * @type Section
 *
 * @prop {string} bg: custom HEXCODE (#FFFFFF)
 * @prop {string} bgGradient: use gradient for background?
 * @prop {string} borderRadius: use gradient for background?
 * @prop {boolean} align: align text to center?
 * @prop {string} padding: add padding to section
 */
var Section = _styledComponents.default.section.withConfig({
  displayName: "global__Section",
  componentId: "wozf93-0"
})(["background:", ";border-radius:", ";text-align:", ";padding:", ";"], function (props) {
  return props.bgGradient ? "linear-gradient(".concat(props.bgGradient, ")") : props.bg ? props.bg : 'none';
}, function (props) {
  return props.borderRadius;
}, function (props) {
  return props.align;
}, function (props) {
  return props.padding;
});
/**
 * GridSection Component
 * @extends Section
 *
 * @prop {string} split: split columns with this config
 * @prop {string} tabletSplit: add split to section (on tablet)
 * @prop {string} mobileSplit: split columns (on mobile)
 * @prop {string} gap: add grid-gap (gutter)
 * @prop {string} tabletGap: add gap to section (on tablet)
 * @prop {string} width: set grid section width
 * @prop {string} tabletWidth: add width to section (on tablet)
 * @prop {string} mobileWidth: set width (on mobile)
 * @prop {string} margin: sets margin to the Grid Section
 * @prop {string} padding: add padding to section
 * @prop {string} mobilePadding: add padding to section (on mobile)
 * @prop {string} tabletPadding: add padding to section (on tablet)
 * @prop {boolean} alignVertically: align items vertically centered?
 * @prop {boolean} alignBottom: align items to bottom?
 * @prop {boolean} justifyCenter: justifies all the children center
 * @prop {boolean} sameHeightChildren: set same height to all children
 */


exports.Section = Section;
var GridSection = (0, _styledComponents.default)(Section).withConfig({
  displayName: "global__GridSection",
  componentId: "wozf93-1"
})(["display:grid;grid-template-columns:", ";grid-gap:", ";grid-auto-rows:", ";width:", ";margin:", ";align-items:", ";justify-items:", ";@media screen and (max-width:1280px){padding:", ";width:", ";grid-template-columns:", ";grid-gap:", ";}@media screen and (max-width:824px){padding:", ";grid-template-columns:", ";grid-gap:", ";width:", ";}"], function (props) {
  return props.split ? props.split : '1fr 1fr';
}, function (props) {
  return props.gap ? props.gap : '0';
}, function (props) {
  return props.sameHeightChildren ? '1fr' : 'auto';
}, function (props) {
  return props.width ? "".concat(props.width, "%") : 'auto';
}, function (props) {
  return props.margin ? props.margin : props.width ? '0 auto' : 'auto';
}, function (props) {
  return props.alignVertically ? 'center' : props.sameHeightChildren ? 'stretch' : props.alignBottom ? 'end' : 'start';
}, function (props) {
  return props.justifyCenter ? 'center' : 'stretch';
}, function (props) {
  return props.tabletPadding ? props.tabletPadding : props.padding;
}, function (props) {
  return props.tabletWidth ? "".concat(props.tabletWidth, "%") : 'auto';
}, function (props) {
  return props.tabletSplit ? props.tabletSplit : props.split ? props.split : '1fr 1fr';
}, function (props) {
  return props.tabletGap ? props.tabletGap : props.gap ? props.gap : '0';
}, function (props) {
  return props.mobilePadding ? props.mobilePadding : props.padding;
}, function (props) {
  return props.mobileSplit ? props.mobileSplit : props.split ? props.split : '1fr 1fr';
}, function (props) {
  return props.mobileGap ? props.mobileGap : props.gap ? props.gap : '0';
}, function (props) {
  return props.mobileWidth ? "".concat(props.mobileWidth, "%") : 'auto';
});
exports.GridSection = GridSection;
;

(function () {
  var reactHotLoader = require('react-hot-loader').default;

  var leaveModule = require('react-hot-loader').leaveModule;

  if (!reactHotLoader) {
    return;
  }

  reactHotLoader.register(Section, "Section", "/Users/user1/Documents/projects/proponents/src/helpers/global.js");
  reactHotLoader.register(GridSection, "GridSection", "/Users/user1/Documents/projects/proponents/src/helpers/global.js");
  leaveModule(module);
})();

;